Runner

Trait Runner 

pub trait Runner {
    // Required method
    fn run(
        &self,
        name: &str,
        testcase: &TestCase,
        context: &ExecutionContext,
    ) -> Result<Output>;
}
A thing that runs the shell expression of a single crate::testcase::TestCase within the given crate::executors::context::Context.

Required Methods

fn run( &self, name: &str, testcase: &TestCase, context: &ExecutionContext, ) -> Result<Output>

Return the crate::output::Output of running the shell expression of a crate::testcase::TestCase

Implementors